@@ -3,8 +3,6 @@ asyncapi
 """
 
 __version__ = '0.2.0'
-
-
 import importlib
 import io
 from collections import deque
@@ -13,6 +11,7 @@ from typing import Any, Dict, Optional
 import requests
 import yaml
 from broadcaster import Broadcast
+from jsondaora import jsonschema_asdataclass
 
 from .api import AsyncApi, OperationsTypeHint
 from .entities import (
@@ -30,12 +29,34 @@ from .exceptions import ReferenceNotFoundError
 
 def build_api(
     path: str,
-    server: str = 'development',
-    operations_module: str = '',
+    server: Optional[str] = None,
+    module_name: str = '',
     republish_errors: bool = True,
 ) -> AsyncApi:
     spec = build_spec(load_spec_dict(path))
-    operations = build_channel_operations(spec, operations_module)
+    return build_api_from_spec(spec, module_name, server, republish_errors)
+
+
+def build_api_auto_spec(
+    module_name: str,
+    server: Optional[str] = None,
+    republish_errors: bool = True,
+) -> AsyncApi:
+    spec = getattr(importlib.import_module(module_name), 'spec')
+    return build_api_from_spec(spec, module_name, server, republish_errors)
+
+
+def build_api_from_spec(
+    spec: Specification,
+    module_name: str,
+    server: Optional[str],
+    republish_errors: bool,
+) -> AsyncApi:
+    operations = build_channel_operations(spec, module_name)
+
+    if server is None:
+        server = tuple(spec.servers.keys())[-1]
+
     protocol = spec.servers[server].protocol.value
     url = spec.servers[server].url
     broadcast = Broadcast(f'{protocol}://{url}')
@@ -44,28 +65,13 @@ def build_api(
     )
 
 
-def build_api_auto_spec(
-    server_url: str,
-    channel: str,
-    operations_module: str = '',
-    operation_id: Optional[str] = None,
-    republish_errors: bool = True,
-) -> AsyncApi:
-    spec = build_auto_spec(server_url, channel, operation_id)
-    operations = build_channel_operations(spec, operations_module)
-    broadcast = Broadcast(server_url)
-    return AsyncApi(
-        spec, operations, broadcast, republish_error_messages=republish_errors
-    )
-
-
 def build_channel_operations(
-    spec: Specification, operations_module: str
+    spec: Specification, module_name: str
 ) -> OperationsTypeHint:
-    if operations_module:
+    if module_name:
         return {
             (channel_name, channel.subscribe.operation_id): getattr(
-                importlib.import_module(operations_module),
+                importlib.import_module(module_name),
                 channel.subscribe.operation_id,
             )
             for channel_name, channel in spec.channels.items()
@@ -93,23 +99,6 @@ def load_spec_dict(path: str) -> Dict[str, Any]:
     return spec
 
 
-def build_auto_spec(
-    server_url: str, channel: str, operation_id: Optional[str]
-) -> Specification:
-    description = f'automatic generated api for {channel}'
-    info = Info(f'{channel} api', '1.0.0', description)
-    protocol, url = server_url.split('://')
-    servers = {
-        'automatic': Server(
-            'automatic', url, ProtocolType(protocol), description
-        )
-    }
-    message = Message('message', 'message', 'message', 'application/json', {})
-    subscribe = Subscribe(message, operation_id)
-    channels = {channel: Channel(channel, description, subscribe)}
-    return Specification(info, servers, channels)
-
-
 def build_spec(spec: Dict[str, Any]) -> Specification:
     fill_refs(spec)
 
@@ -131,12 +120,20 @@ def build_spec(spec: Dict[str, Any]) -> Specification:
                         content_type=channel_spec['subscribe']['message'].get(
                             'contentType', spec.get('defaultContentType')
                         ),
+                        payload=jsonschema_asdataclass(
+                            channel_spec['subscribe']['message'][
+                                'name'
+                            ].replace(' ', ''),
+                            channel_spec['subscribe']['message'].get(
+                                'payload'
+                            ),
+                        ),
                         **{
                             k: v
                             for k, v in channel_spec['subscribe'][
                                 'message'
                             ].items()
-                            if k != 'contentType'
+                            if k != 'contentType' and k != 'payload'
                         },
                     ),
                     operation_id=channel_spec.pop('subscribe').get(
@@ -153,7 +150,15 @@ def build_spec(spec: Dict[str, Any]) -> Specification:
                     content_type=message.get(
                         'contentType', spec.get('defaultContentType')
                     ),
-                    **{k: v for k, v in message.items() if k != 'contentType'},
+                    payload=jsonschema_asdataclass(
+                        message['name'].replace(' ', ''),
+                        message.get('payload'),
+                    ),
+                    **{
+                        k: v
+                        for k, v in message.items()
+                        if k != 'contentType' and k != 'payload'
+                    },
                 )
                 for msg_id, message in spec['components']['messages'].items()
             }
